@@ -5,7 +5,7 @@
 ##############################################################
 
 # Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-# Version: 0.4.4-6
+# Version: 0.4.4-8
 
 import os
 import sys
@@ -41,13 +41,23 @@ ConfigFile                   = 'smscon_config'        # name of config file
 
 ##############################################################
 
+# Check if configuration file exists.
+try:
+  f = open(MainPath + ConfigFile, 'r')
+  f.close()
+except:
+  message = 'Reading SMSCON settings gave a FATAL ERROR while loading\nThe configuration file does not exist or it is corrupted.'
+  showMessage(message)
+  sys.exit(1)
+
+# Make a copy of the configuration for safe editing.  
 os.system('cp /usr/bin/smscon_config /home/user/')    # make a copy of the config file 
 
 ##############################################################
 
 def doUpdateConfig():
     """
-    Update the config file with the newly created and restart deamon.
+    Update the config file with the edited and restart deamon.
     """
 
     time.sleep(1)
@@ -243,13 +253,13 @@ class MyForm(QtGui.QMainWindow):
                   
        # Create Methods
 
-##        def doAbout(self):
-##            msg = "SMSCON - Control your N900 through SMS\n\n"
-##            msg += "Version 0.4.6\n\n"
-##            msg += unichr(int('00A9', 16)) + "SMSCON - 2010, Frank Visser\n\n"
-##            msg += unichr(int('00A9', 16)) + "SMSCON Editor - 2010, Christos Zamantzas\n\n"
-##            msg += "Distributed under GPL ver. 3"
-##            QMessageBox.about(self, "About - SMSCON", msg)
+        # def doAbout(self):
+            # msg = "SMSCON - Control your N900 through SMS\n\n"
+            # msg += "Version 0.4.6\n\n"
+            # msg += unichr(int('00A9', 16)) + "SMSCON - 2010, Frank Visser\n\n"
+            # msg += unichr(int('00A9', 16)) + "SMSCON Editor - 2010, Christos Zamantzas\n\n"
+            # msg += "Distributed under GPL ver. 3"
+            # QMessageBox.about(self, "About - SMSCON", msg)
 
         # def doCredits(self):
         
